<?php namespace EscapeWork\Manager\Press\Models;

use EscapeWork\LaravelHelpers\Eloquent;
use InvalidArgumentException;
use Carbon\Carbon;


class Press extends Eloquent
{

    /**
     * Table
     */
    protected $table = 'presses';

    /**
     * Sluggable
     */
    protected $sluggable = true;

    /**
     * Dates array
     */
    protected $dates = array('date');

    /**
     * Regras de validação
     */
    public static $validationRules = array(
        'title'        => array('required'),
        'description'  => array('required'),
        'date'         => array('required'),
    );

    /**
     * Mensagens de validação
     */
    public static $validationMessages = array(
        'title.required'       => 'O título é obrigatório',
        'description.required' => 'A descrição é obrigatória',
        'date.required'        => 'A data é obrigatória',
    );

    /**
     * Fillable fields
     */
    public $fillable = array(
        'id',
        'title',
        'slug',
        'link',
        'description',
        'date',
        'created_at',
        'updated_at',
    );

    /**
     * Retornando o model atual (esta função pode ser sobreescrita)
     */
    public function getMediaModel()
    {
        return 'EscapeWork\Manager\Press\Models\Press';
    }

    /**
     * Escopo para mídia ativa
     */
    public function scopeActive($query)
    {
        return $query->where('active', '=', 1);
    }

    /**
     * Medias relashionship
     */
    public function medias()
    {
        return $this->morphMany('EscapeWork\Manager\Medias\Models\Media', 'medias', 'media_model', 'model_id')
                    ->orderBy('order');
    }

    /**
     * Setting the date
     */
    public function setDateAttribute($value)
    {
        try {
            $this->attributes['date'] = Carbon::createFromFormat('d/m/Y', $value);
        } catch (InvalidArgumentException $e) {
            $this->attributes['date'] = null;
        }
    }

    /**
     * PressDownload relashinship
     */
    public function downloads()
    {
        return $this->hasMany('EscapeWork\Manager\Press\Models\PressDownload', 'press_id');
    }
}
