<?php namespace EscapeWork\Manager\Press\Providers;

use Illuminate\Support\ServiceProvider;
use EscapeWork\Manager\Press\Commands\ConfigureCommand;

class ManagerPressServiceProvider extends ServiceProvider {

	/**
	 * Indicates if loading of the provider is deferred.
	 *
	 * @var bool
	 */
	protected $defer = false;

	/**
	 * Bootstrap the application events.
	 *
	 * @return void
	 */
	public function boot()
	{
		$this->package('escapework/manager-press', 'manager-press', realpath(__DIR__ . '/../../../../'));

        require_once(__DIR__ . '/../../../../routes.php');
	}

	/**
	 * Register the service provider.
	 *
	 * @return void
	 */
	public function register()
	{
		$this->app->bind('EscapeWork\Manager\Press\Repositories\Press\PressRepository', 'EscapeWork\Manager\Press\Repositories\Press\EloquentPressRepository');
        $this->app->bind('EscapeWork\Manager\Press\Repositories\PressDownload\PressDownloadRepository', 'EscapeWork\Manager\Press\Repositories\PressDownload\EloquentPressDownloadRepository');

        $this->registerCommands();

        $this->app['config']->set('manager::packages.manager-press', 'manager-press');
    }

    protected function registerCommands()
    {
        $this->app['command.manager.press.configure'] = $this->app->share(function($app)
        {
            return new ConfigureCommand;
        });

        $this->commands('command.manager.press.configure');
    }

	/**
	 * Get the services provided by the provider.
	 *
	 * @return array
	 */
	public function provides()
	{
		return array('command.manager.press.configure');
	}

}
