@extends(Config::get('manager::views.layouts.master'))

@section('content')
    <ul class="breadcrumb">
        <li><a href="{{ route('manager.home') }}">Home</a> <span class="divider">/</span></li>
        <li class="active">Imprensa</li>
    </ul><!-- .breadcrumb -->

    <div class="page-header">
        <div class="pull-left">
            <h2>Imprensa</h2>
        </div><!-- .pull-left -->

        <div class="pull-right">
            @if (Check::can('press', 'create'))
                <a href="{{ route('manager.press.create') }}" class="btn btn-primary">Inserir nova matéria</a>
            @endif
        </div><!-- .pull-right -->

        <div class="clearfix"></div>
    </div><!-- .page=header -->

    {{ Msg::getAll() }}

    @if (Check::can('press', 'read'))
        <table class="table table-bordered table-striped table-hover">
            <thead>
                <tr>
                    <th>#</th>
                    <th>Título</th>
                    <th>Data</th>
                    <th>Ativo</th>
                    <th>Ação</th>
                </tr>
            </thead>
            <tbody>
                @foreach ($presses as $press)
                    <tr>
                        <td>{{ $press->id }}</td>
                        <td>{{ $press->title }}</td>
                        <td>{{ date('d/m/y', strtotime(str_replace('-', '/', $press->date))) }}</td>
                        <td><input type="checkbox" value="1" data-id="{{ $press->id }}" class="js-update-active" {{ $press->active ? 'checked="checked"' : null }} /></td>
                        <td>
                            <div class="btn-group">
                                <a href="{{ route('manager.midias.index', array($press->id, urlencode($press->getMediaModel()))) }}" class="btn btn-small" title="Editar">
                                    <i class="icon-camera"></i> fotos
                                </a>

                                @if (Check::can('press', 'update'))
                                    <a href="{{ route('manager.press.edit', $press->id) }}" class="btn btn-small" title="Editar">
                                        <i class="icon-pencil"></i> editar
                                    </a>
                                @endif

                                @if (Check::can('press', 'destroy'))
                                    <a href="{{ route('manager.press.destroy', $press->id) }}" class="btn btn-small" data-delete="true" title="Excluir">
                                        <i class="icon-trash"></i> excluir
                                    </a>
                                @endif
                            </div><!-- .btn-group -->
                        </td>
                    <tr>
                @endforeach
            </tbody>
    @endif
@stop

@section('scripts')
    @parent

    <script type="text/javascript">
    (function() {
        window.App = window.App || {};

        App.Manager = App.Manager || {};

        App.Manager.Press = {
            init: function() {
                this.listenEventsActive();
            },

            listenEventsActive: function() {
                var _this = this;

                $('.js-update-active').on('change', function(e) {
                    _this.updateActive($(this));
                });
            },

            updateActive: function($press) {
                var _this  = this,
                    id     = $press.data('id'),
                    active = $press.prop('checked') ? 1 : 0;

                $press.prop('disabled', true)

                $.post('/manager/imprensa/'+id+'/active', {
                    _method: 'put',
                    active: active
                }, function(result) {
                    $press.prop('disabled', false)
                });
            },
        }

        App.Manager.Press.init();
        })();
    </script>
@stop
